import 'bridge.dart';

class TivioDataWidget {
  String id;
  String name;
  Bridge _bridge;

  TivioDataWidget (String id, String name, Bridge bridge) {
    this.id = id;
    this.name = name;
    _bridge = bridge;
  }

  subscribeToChannels(Function(TivioDataChannel) callback) {
    return this._bridge.subscribeToChannels(this.id, callback);
  }

  unsubscribeToChannels() {
    // TD add support of unsubscribing concrete callback
    this._bridge.unsubscribeToChannels();
  }
}

class _ChannelImages {
  String logo;
  String cover;

  _ChannelImages (String logo, String cover) {
    this.logo = logo;
    this.cover = cover;
  }
}

class TivioDataChannel {
  String id;
  String name;
  _ChannelImages images;
  Bridge _bridge;

  TivioDataChannel (String id, String name, String logo, String cover, Bridge bridge) {
    this.id = id;
    this.name = name;
    this.images = new _ChannelImages(logo, cover);
    _bridge = bridge;
  }

  subscribeToSections(Function(TivioDataSection) callback) {
    return this._bridge.subscribeToSections(this.id, callback);
  }

  unsubscribeToSections() {
    this._bridge.unsubscribeToSections();
  }
}

class TivioDataSection {
  String id;
  String name;
  Bridge _bridge;

  TivioDataSection (String id, String name, Bridge bridge) {
    this.id = id;
    this.name = name;
    _bridge = bridge;
  }

  subscribeToVideos(Function(TivioDataVideo) callback) {
    return _bridge.subscribeToVideos(this.id, callback);
  }

  unsubscribeToVideos() {
    _bridge.unsubscribeToVideos();
  }
}

class _Url {
  String hls;

  _Url (this.hls);
}

class _VideoImages {
  String cover;

  _VideoImages (this.cover);
}

class TivioDataVideo {
  String id;
  String name;
  Duration duration;
  DateTime created;
  _Url url;
  _VideoImages images;

  TivioDataVideo (String id, String name, int duration, DateTime created, String hls, String cover) {
    this.id = id;
    this.name = name;
    this.duration = Duration(milliseconds: duration);
    this.created = created;
    this.url = new _Url(hls);
    this.images = new _VideoImages(cover);
  }
}

class TivioDataPagination<T> {
  List<T> records;
  bool hasNextPage;

  TivioDataPagination(List<T> records, bool hasNextPage) {
    this.records = records;
    this.hasNextPage = hasNextPage;
  }
}
